pub fn to_ndjson(changeset: &ChangeSet) -> Result<String, ChangeSetError>Expand description
Encodes the envelope as line one and each op on a following line, in order.
The returned in-memory string ends every line, including the last, with \n.
Errors
Returns ChangeSetError::Serialize if any envelope or op cannot serialize.